
Name:           python-pytest
Version:        3.0.2
Release:        62.2
Summary:        Simple powerful testing with Python
License:        MIT
Group:          Development/Languages/Python
Url:            http://pytest.org
Source:         https://files.pythonhosted.org/packages/source/p/pytest/pytest-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  unzip
BuildRequires:  python-devel
BuildRequires:  python-py >= 1.4.25
BuildRequires:  python-setuptools
Requires:       python-py >= 1.4.29
Requires(post): chkconfig
Requires(preun): chkconfig
#/usr/bin/py.test imports pkg_resources
Requires:       python-setuptools
BuildArch:      noarch

%description
pytest helps you write better programs. It is a a mature full-featured,
cross-project Python testing tool. It provides:

* auto-discovery of test modules and functions,
* detailed info on failing assert statements (no need to remember 
  self.assert* names),
* modular fixtures for managing small or parametrized long-lived test resources.
* multi-paradigm support: you can use py.test to run test suites based on 
  unittest (or trial), nose,
* single-source compatibility to Python2.4 all the way up to Python3.3, 
  PyPy-1.9 and Jython-2.5.1, and
* many external plugins.


%prep
%setup -q -n pytest-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for p in py.test pytest ; do
    mv %{buildroot}%{_bindir}/$p %{buildroot}%{_bindir}/$p-%{py_ver}
    ln -s -f %{_sysconfdir}/alternatives/$p %{buildroot}%{_bindir}/$p
done

%post
update-alternatives \
    --install %{_bindir}/py.test py.test %{_bindir}/py.test-%{py_ver} 20 \
   --slave %{_bindir}/pytest pytest %{_bindir}/pytest-%{py_ver}

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove py.test %{_bindir}/py.test-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE README.rst
%{_bindir}/py.test
%{_bindir}/pytest
%{_bindir}/py.test-%{py_ver}
%{_bindir}/pytest-%{py_ver}
%ghost %{_sysconfdir}/alternatives/py.test
%ghost %{_sysconfdir}/alternatives/pytest
%{python_sitelib}/*

%changelog
* Fri Sep 16 2016 toddrme2178@gmail.com
- Fix download url.
* Thu Sep 15 2016 toddrme2178@gmail.com
- update to version 3.0.2
  * Improve error message when passing non-string ids to ``pytest.mark.parametrize`` (`#1857`_).
    Thanks `@okken`_ for the report and `@nicoddemus`_ for the PR.
  * Add ``buffer`` attribute to stdin stub class ``pytest.capture.DontReadFromInput``
    Thanks `@joguSD`_ for the PR.
  * Fix ``UnicodeEncodeError`` when string comparison with unicode has failed. (`#1864`_)
    Thanks `@AiOO`_ for the PR.
  * ``pytest_plugins`` is now handled correctly if defined as a string (as opposed as
    a sequence of strings) when modules are considered for assertion rewriting.
    Due to this bug, much more modules were being rewritten than necessary
    if a test suite uses ``pytest_plugins`` to load internal plugins (`#1888`_).
    Thanks `@jaraco`_ for the report and `@nicoddemus`_ for the PR (`#1891`_).
  * Do not call tearDown and cleanups when running tests from
    ``unittest.TestCase`` subclasses with ``--pdb``
    enabled. This allows proper post mortem debugging for all applications
    which have significant logic in their tearDown machinery (`#1890`_). Thanks
    `@mbyt`_ for the PR.
  * Fix use of deprecated ``getfuncargvalue`` method in the internal doctest plugin.
    Thanks `@ViviCoder`_ for the report (`#1898`_).
- update to version 3.0.1
  * Fix regression when ``importorskip`` is used at module level (`#1822`_).
    Thanks `@jaraco`_ and `@The-Compiler`_ for the report and `@nicoddemus`_ for the PR.
  * Fix parametrization scope when session fixtures are used in conjunction
    with normal parameters in the same call (`#1832`_).
    Thanks `@The-Compiler`_ for the report, `@Kingdread`_ and `@nicoddemus`_ for the PR.
  * Fix internal error when parametrizing tests or fixtures using an empty ``ids`` argument (`#1849`_).
    Thanks `@OPpuolitaival`_ for the report and `@nicoddemus`_ for the PR.
  * Fix loader error when running ``pytest`` embedded in a zipfile.
    Thanks `@mbachry`_ for the PR.
- update to version 3.0.0
  + Incompatible changes
  * Reinterpretation mode has now been removed.  Only plain and rewrite
    mode are available, consequently the ``--assert=reinterp`` option is
    no longer available.  Thanks `@flub`_ for the PR.
  * The following deprecated commandline options were removed:
  * ``--genscript``: no longer supported;
    > ``--no-assert``: use ``--assert=plain`` instead;
    > ``--nomagic``: use ``--assert=plain`` instead;
    > ``--report``: use ``-r`` instead;
  * ImportErrors in plugins now are a fatal error instead of issuing a
    pytest warning (`#1479`_). Thanks to `@The-Compiler`_ for the PR.
  * Removed support code for Python 3 versions < 3.3 (`#1627`_).
  * Removed all ``py.test-X*`` entry points. The versioned, suffixed entry points
    were never documented and a leftover from a pre-virtualenv era. These entry
    points also created broken entry points in wheels, so removing them also
    removes a source of confusion for users (`#1632`_).
    Thanks `@obestwalter`_ for the PR.
  * ``pytest.skip()`` now raises an error when used to decorate a test function,
    as opposed to its original intent (to imperatively skip a test inside a test function). Previously
    this usage would cause the entire module to be skipped (`#607`_).
    Thanks `@omarkohl`_ for the complete PR (`#1519`_).
  * Exit tests if a collection error occurs. A poll indicated most users will hit CTRL-C
    anyway as soon as they see collection errors, so pytest might as well make that the default behavior (`#1421`_).
    A ``--continue-on-collection-errors`` option has been added to restore the previous behaviour.
    Thanks `@olegpidsadnyi`_ and `@omarkohl`_ for the complete PR (`#1628`_).
  * Renamed the pytest ``pdb`` module (plugin) into ``debugging`` to avoid clashes with the builtin ``pdb`` module.
  * Raise a helpful failure message when requesting a parametrized fixture at runtime,
    e.g. with ``request.getfixturevalue``. Previously these parameters were simply
    never defined, so a fixture decorated like ``@pytest.fixture(params=[0, 1, 2])``
    only ran once (`#460`_).
    Thanks to `@nikratio`_ for the bug report, `@RedBeardCode`_ and `@tomviner`_ for the PR.
  * ``_pytest.monkeypatch.monkeypatch`` class has been renamed to ``_pytest.monkeypatch.MonkeyPatch``
    so it doesn't conflict with the ``monkeypatch`` fixture.
  * ``--exitfirst / -x`` can now be overridden by a following ``--maxfail=N``
    and is just a synonym for ``--maxfail=1``.
    + New Features
  * Support nose-style ``__test__`` attribute on methods of classes,
    including unittest-style Classes. If set to ``False``, the test will not be
    collected.
  * New ``doctest_namespace`` fixture for injecting names into the
    namespace in which doctests run.
    Thanks `@milliams`_ for the complete PR (`#1428`_).
  * New ``--doctest-report`` option available to change the output format of diffs
    when running (failing) doctests (implements `#1749`_).
    Thanks `@hartym`_ for the PR.
  * New ``name`` argument to ``pytest.fixture`` decorator which allows a custom name
    for a fixture (to solve the funcarg-shadowing-fixture problem).
    Thanks `@novas0x2a`_ for the complete PR (`#1444`_).
  * New ``approx()`` function for easily comparing floating-point numbers in
    tests.
    Thanks `@kalekundert`_ for the complete PR (`#1441`_).
  * Ability to add global properties in the final xunit output file by accessing
    the internal ``junitxml`` plugin (experimental).
    Thanks `@tareqalayan`_ for the complete PR `#1454`_).
  * New ``ExceptionInfo.match()`` method to match a regular expression on the
    string representation of an exception (`#372`_).
    Thanks `@omarkohl`_ for the complete PR (`#1502`_).
  * ``__tracebackhide__`` can now also be set to a callable which then can decide
    whether to filter the traceback based on the ``ExceptionInfo`` object passed
    to it. Thanks `@The-Compiler`_ for the complete PR (`#1526`_).
  * New ``pytest_make_parametrize_id(config, val)`` hook which can be used by plugins to provide
    friendly strings for custom types.
    Thanks `@palaviv`_ for the PR.
  * ``capsys`` and ``capfd`` now have a ``disabled()`` context-manager method, which
    can be used to temporarily disable capture within a test.
    Thanks `@nicoddemus`_ for the PR.
  * New cli flag ``--fixtures-per-test``: shows which fixtures are being used
    for each selected test item. Features doc strings of fixtures by default.
    Can also show where fixtures are defined if combined with ``-v``.
    Thanks `@hackebrot`_ for the PR.
  * Introduce ``pytest`` command as recommended entry point. Note that ``py.test``
    still works and is not scheduled for removal. Closes proposal
    `#1629`_. Thanks `@obestwalter`_ and `@davehunt`_ for the complete PR
    (`#1633`_).
  * New cli flags:
    > ``--setup-plan``: performs normal collection and reports
    the potential setup and teardown and does not execute any fixtures and tests;
    > ``--setup-only``: performs normal collection, executes setup and teardown of
    fixtures and reports them;
    > ``--setup-show``: performs normal test execution and additionally shows
    setup and teardown of fixtures;
    > ``--keep-duplicates``: py.test now ignores duplicated paths given in the command
    line. To retain the previous behavior where the same test could be run multiple
    times by specifying it in the command-line multiple times, pass the ``--keep-duplicates``
    argument (`#1609`_);
    Thanks `@d6e`_, `@kvas-it`_, `@sallner`_, `@ioggstream`_ and `@omarkohl`_ for the PRs.
  * New CLI flag ``--override-ini``/``-o``: overrides values from the ini file.
    For example: ``"-o xfail_strict=True"``'.
    Thanks `@blueyed`_ and `@fengxx`_ for the PR.
  * New hooks:
    > ``pytest_fixture_setup(fixturedef, request)``: executes fixture setup;
    > ``pytest_fixture_post_finalizer(fixturedef)``: called after the fixture's
    finalizer and has access to the fixture's result cache.
    Thanks `@d6e`_, `@sallner`_.
  * Issue warnings for asserts whose test is a tuple literal. Such asserts will
    never fail because tuples are always truthy and are usually a mistake
    (see `#1562`_). Thanks `@kvas-it`_, for the PR.
  * Allow passing a custom debugger class (e.g. ``--pdbcls=IPython.core.debugger:Pdb``).
    Thanks to `@anntzer`_ for the PR.
  + Changes
  * Plugins now benefit from assertion rewriting.  Thanks
    `@sober7`_, `@nicoddemus`_ and `@flub`_ for the PR.
  * Change ``report.outcome`` for ``xpassed`` tests to ``"passed"`` in non-strict
    mode and ``"failed"`` in strict mode. Thanks to `@hackebrot`_ for the PR
    (`#1795`_) and `@gprasad84`_ for report (`#1546`_).
  * Tests marked with ``xfail(strict=False)`` (the default) now appear in
    JUnitXML reports as passing tests instead of skipped.
    Thanks to `@hackebrot`_ for the PR (`#1795`_).
  * Highlight path of the file location in the error report to make it easier to copy/paste.
    Thanks `@suzaku`_ for the PR (`#1778`_).
  * Fixtures marked with ``@pytest.fixture`` can now use ``yield`` statements exactly like
    those marked with the ``@pytest.yield_fixture`` decorator. This change renders
    ``@pytest.yield_fixture`` deprecated and makes ``@pytest.fixture`` with ``yield`` statements
    the preferred way to write teardown code (`#1461`_).
    Thanks `@csaftoiu`_ for bringing this to attention and `@nicoddemus`_ for the PR.
  * Explicitly passed parametrize ids do not get escaped to ascii (`#1351`_).
    Thanks `@ceridwen`_ for the PR.
  * Fixtures are now sorted in the error message displayed when an unknown
    fixture is declared in a test function.
    Thanks `@nicoddemus`_ for the PR.
  * ``pytest_terminal_summary`` hook now receives the ``exitstatus``
    of the test session as argument. Thanks `@blueyed`_ for the PR (`#1809`_).
  * Parametrize ids can accept ``None`` as specific test id, in which case the
    automatically generated id for that argument will be used.
    Thanks `@palaviv`_ for the complete PR (`#1468`_).
  * The parameter to xunit-style setup/teardown methods (``setup_method``,
    ``setup_module``, etc.) is now optional and may be omitted.
    Thanks `@okken`_ for bringing this to attention and `@nicoddemus`_ for the PR.
  * Improved automatic id generation selection in case of duplicate ids in
    parametrize.
    Thanks `@palaviv`_ for the complete PR (`#1474`_).
  * Now pytest warnings summary is shown up by default. Added a new flag
    ``--disable-pytest-warnings`` to explicitly disable the warnings summary (`#1668`_).
  * Make ImportError during collection more explicit by reminding
    the user to check the name of the test module/package(s) (`#1426`_).
    Thanks `@omarkohl`_ for the complete PR (`#1520`_).
  * Add ``build/`` and ``dist/`` to the default ``--norecursedirs`` list. Thanks
    `@mikofski`_ for the report and `@tomviner`_ for the PR (`#1544`_).
  * ``pytest.raises`` in the context manager form accepts a custom
    ``message`` to raise when no exception occurred.
    Thanks `@palaviv`_ for the complete PR (`#1616`_).
  * ``conftest.py`` files now benefit from assertion rewriting; previously it
    was only available for test modules. Thanks `@flub`_, `@sober7`_ and
    `@nicoddemus`_ for the PR (`#1619`_).
  * Text documents without any doctests no longer appear as "skipped".
    Thanks `@graingert`_ for reporting and providing a full PR (`#1580`_).
  * Ensure that a module within a namespace package can be found when it
    is specified on the command line together with the ``--pyargs``
    option.  Thanks to `@taschini`_ for the PR (`#1597`_).
  * Always include full assertion explanation during assertion rewriting. The previous behaviour was hiding
    sub-expressions that happened to be ``False``, assuming this was redundant information.
    Thanks `@bagerard`_ for reporting (`#1503`_). Thanks to `@davehunt`_ and
    `@tomviner`_ for the PR.
  * ``OptionGroup.addoption()`` now checks if option names were already
    added before, to make it easier to track down issues like `#1618`_.
    Before, you only got exceptions later from ``argparse`` library,
    giving no clue about the actual reason for double-added options.
  * ``yield``-based tests are considered deprecated and will be removed in pytest-4.0.
    Thanks `@nicoddemus`_ for the PR.
  * ``[pytest]`` sections in ``setup.cfg`` files should now be named ``[tool:pytest]``
    to avoid conflicts with other distutils commands (see `#567`_). ``[pytest]`` sections in
    ``pytest.ini`` or ``tox.ini`` files are supported and unchanged.
    Thanks `@nicoddemus`_ for the PR.
  * Using ``pytest_funcarg__`` prefix to declare fixtures is considered deprecated and will be
    removed in pytest-4.0 (`#1684`_).
    Thanks `@nicoddemus`_ for the PR.
  * Passing a command-line string to ``pytest.main()`` is considered deprecated and scheduled
    for removal in pytest-4.0. It is recommended to pass a list of arguments instead (`#1723`_).
  * Rename ``getfuncargvalue`` to ``getfixturevalue``. ``getfuncargvalue`` is
    still present but is now considered deprecated. Thanks to `@RedBeardCode`_ and `@tomviner`_
    for the PR (`#1626`_).
  * ``optparse`` type usage now triggers DeprecationWarnings (`#1740`_).
  * ``optparse`` backward compatibility supports float/complex types (`#457`_).
  * Refined logic for determining the ``rootdir``, considering only valid
    paths which fixes a number of issues: `#1594`_, `#1435`_ and `#1471`_.
    Updated the documentation according to current behavior. Thanks to
    `@blueyed`_, `@davehunt`_ and `@matthiasha`_ for the PR.
  * Always include full assertion explanation. The previous behaviour was hiding
    sub-expressions that happened to be False, assuming this was redundant information.
    Thanks `@bagerard`_ for reporting (`#1503`_). Thanks to `@davehunt`_ and
    `@tomviner`_ for PR.
  * Better message in case of not using parametrized variable (see `#1539`_).
    Thanks to `@tramwaj29`_ for the PR.
  * Updated docstrings with a more uniform style.
  * Add stderr write for ``pytest.exit(msg)`` during startup. Previously the message was never shown.
    Thanks `@BeyondEvil`_ for reporting `#1210`_. Thanks to `@JonathonSonesen`_ and
    `@tomviner`_ for the PR.
  * No longer display the incorrect test deselection reason (`#1372`_).
    Thanks `@ronnypfannschmidt`_ for the PR.
  * The ``--resultlog`` command line option has been deprecated: it is little used
    and there are more modern and better alternatives (see `#830`_).
    Thanks `@nicoddemus`_ for the PR.
  * Improve error message with fixture lookup errors: add an 'E' to the first
    line and '>' to the rest. Fixes `#717`_. Thanks `@blueyed`_ for reporting and
    a PR, `@eolo999`_ for the initial PR and `@tomviner`_ for his guidance during
    EuroPython2016 sprint.
  + Bug Fixes
  * Parametrize now correctly handles duplicated test ids.
  * Fix internal error issue when the ``method`` argument is missing for
    ``teardown_method()`` (`#1605`_).
  * Fix exception visualization in case the current working directory (CWD) gets
    deleted during testing (`#1235`_). Thanks `@bukzor`_ for reporting. PR by
    `@marscher`_.
  * Improve test output for logical expression with brackets (`#925`_).
    Thanks `@DRMacIver`_ for reporting and `@RedBeardCode`_ for the PR.
  * Create correct diff for strings ending with newlines (`#1553`_).
    Thanks `@Vogtinator`_ for reporting and `@RedBeardCode`_ and
    `@tomviner`_ for the PR.
  * ``ConftestImportFailure`` now shows the traceback making it easier to
    identify bugs in ``conftest.py`` files (`#1516`_). Thanks `@txomon`_ for
    the PR.
  * Text documents without any doctests no longer appear as "skipped".
    Thanks `@graingert`_ for reporting and providing a full PR (`#1580`_).
  * Fixed collection of classes with custom ``__new__`` method.
    Fixes `#1579`_. Thanks to `@Stranger6667`_ for the PR.
  * Fixed scope overriding inside metafunc.parametrize (`#634`_).
    Thanks to `@Stranger6667`_ for the PR.
  * Fixed the total tests tally in junit xml output (`#1798`_).
    Thanks to `@cryporchild`_ for the PR.
  * Fixed off-by-one error with lines from ``request.node.warn``.
    Thanks to `@blueyed`_ for the PR.
- update to version 2.9.2:
  * fix #510: skip tests where one parameterize dimension was empty
    thanks Alex Stapleton for the Report and @RonnyPfannschmidt for
    the PR
  * Fix Xfail does not work with condition keyword argument. Thanks
    @astraw38 for reporting the issue (#1496) and @tomviner for PR the
    (#1524).
  * Fix win32 path issue when puttinging custom config file with
    absolute path in pytest.main("-c your_absolute_path").
  * Fix maximum recursion depth detection when raised error class is
    not aware of unicode/encoded bytes. Thanks @prusse-martin for the
    PR (#1506).
  * Fix pytest.mark.skip mark when used in strict mode. Thanks
    @pquentin for the PR and @RonnyPfannschmidt for showing how to fix
    the bug.
  * Minor improvements and fixes to the documentation. Thanks
    @omarkohl for the PR.
  * Fix --fixtures to show all fixture definitions as opposed to just
    one per fixture name. Thanks to @hackebrot for the PR.
- update to version 2.9.1:
  * Improve error message when a plugin fails to load. Thanks
    @nicoddemus for the PR.
  * Fix (#1178): pytest.fail with non-ascii characters raises an
    internal pytest error. Thanks @nicoddemus for the PR.
  * Fix (#469): junit parses report.nodeid incorrectly, when params
    IDs contain ::. Thanks @tomviner for the PR (#1431).
  * Fix (#578): SyntaxErrors containing non-ascii lines at the point
    of failure generated an internal py.test error. Thanks @asottile
    for the report and @nicoddemus for the PR.
  * Fix (#1437): When passing in a bytestring regex pattern to
    parameterize attempt to decode it as utf-8 ignoring errors.
  * Fix (#649): parametrized test nodes cannot be specified to run on
    the command line.
- update to version 2.9.0:
  * New Features
    + New pytest.mark.skip mark, which unconditionally skips marked
    tests. Thanks @MichaelAquilina for the complete PR (#1040).
    + --doctest-glob may now be passed multiple times in the
    command-line. Thanks @jab and @nicoddemus for the PR.
    + New -rp and -rP reporting options give the summary and full
    output of passing tests, respectively. Thanks to @codewarrior0 for
    the PR.
    + pytest.mark.xfail now has a strict option which makes XPASS
    tests to fail the test suite, defaulting to False. There’s also a
    xfail_strict ini option that can be used to configure it
    project-wise. Thanks @rabbbit for the request and @nicoddemus for
    the PR (#1355).
    + Parser.addini now supports options of type bool. Thanks
    @nicoddemus for the PR.
    + New ALLOW_BYTES doctest option strips b prefixes from byte
    strings in doctest output (similar to ALLOW_UNICODE). Thanks
    @jaraco for the request and @nicoddemus for the PR (#1287).
    + give a hint on KeyboardInterrupt to use the –fulltrace option to
    show the errors, this fixes #1366. Thanks to @hpk42 for the report
    and @RonnyPfannschmidt for the PR.
    + catch IndexError exceptions when getting exception source
    location. This fixes pytest internal error for dynamically
    generated code (fixtures and tests) where source lines are fake by
    intention
  * Changes
    + Important: py.code has been merged into the pytest repository as
    pytest._code. This decision was made because py.code had very few
    uses outside pytest and the fact that it was in a different
    repository made it difficult to fix bugs on its code in a timely
    manner. The team hopes with this to be able to better refactor out
    and improve that code. This change shouldn’t affect users, but it
    is useful to let users aware if they encounter any strange
    behavior.
    + Keep in mind that the code for pytest._code is private and
    experimental, so you definitely should not import it explicitly!
    + Please note that the original py.code is still available in
    pylib.
    + pytest_enter_pdb now optionally receives the pytest config
    object. Thanks @nicoddemus for the PR.
    + Removed code and documentation for Python 2.5 or lower versions,
    including removal of the obsolete _pytest.assertion.oldinterpret
    module. Thanks @nicoddemus for the PR (#1226).
    + Comparisons now always show up in full when CI or BUILD_NUMBER
    is found in the environment, even when -vv isn’t used. Thanks
    @The-Compiler for the PR.
    + --lf and --ff now support long names: --last-failed and
  - -failed-first respectively. Thanks @MichaelAquilina for the PR.
    + Added expected exceptions to pytest.raises fail message
    + Collection only displays progress (“collecting X items”) when in
    a terminal. This avoids cluttering the output when using
  - -color=yes to obtain colors in CI integrations systems (#1397).
  * Bug Fixes
    + The -s and -c options should now work under xdist;
    Config.fromdictargs now represents its input much more
    faithfully. Thanks to @bukzor for the complete PR (#680).
    + Fix (#1290): support Python 3.5’s @ operator in assertion
    rewriting. Thanks @Shinkenjoe for report with test case and
    @tomviner for the PR.
    + Fix formatting utf-8 explanation messages (#1379). Thanks @biern
    for the PR.
    + Fix traceback style docs to describe all of the available
    options (auto/long/short/line/native/no), with auto being the
    default since v2.6. Thanks @hackebrot for the PR.
    + Fix (#1422): junit record_xml_property doesn’t allow multiple
    records with same name.
- update to version 2.8.7:
  * fix #1338: use predictable object resolution for monkeypatch
- changes from version 2.8.6:
  * fix #1259: allow for double nodeids in junitxml, this was a
    regression failing plugins combinations like pytest-pep8 +
    pytest-flakes
  * Workaround for exception that occurs in pyreadline when using
  - -pdb with standard I/O capture enabled. Thanks Erik M. Bray for
    the PR.
  * fix #900: Better error message in case the target of a monkeypatch
    call raises an ImportError.
  * fix #1292: monkeypatch calls (setattr, setenv, etc.) are now
    O(1). Thanks David R. MacIver for the report and Bruno Oliveira
    for the PR.
  * fix #1223: captured stdout and stderr are now properly displayed
    before entering pdb when --pdb is used instead of being thrown
    away. Thanks Cal Leeming for the PR.
  * fix #1305: pytest warnings emitted during pytest_terminal_summary
    are now properly displayed. Thanks Ionel Maries Cristian for the
    report and Bruno Oliveira for the PR.
  * fix #628: fixed internal UnicodeDecodeError when doctests contain
    unicode. Thanks Jason R. Coombs for the report and Bruno Oliveira
    for the PR.
  * fix #1334: Add captured stdout to jUnit XML report on setup
    error. Thanks Georgy Dyuldin for the PR.
- Update to version 2.8.5
  * fix #1243: fixed issue where class attributes injected during
    collection could break pytest.
    fix #1074: precompute junitxml chunks instead of storing the
    whole tree in objects
    fix #1238: fix pytest.deprecated_call() receiving multiple
    arguments (Regression introduced in 2.8.4).
- update to version 2.8.4:
  * fix #1190: deprecated_call() now works when the deprecated
    function has been already called by another test in the same
    module. Thanks Mikhail Chernykh for the report and Bruno Oliveira
    for the PR.
  * fix #1198: --pastebin option now works on Python 3. Thanks Mehdy
    Khoshnoody for the PR.
  * fix #1219: --pastebin now works correctly when captured output
    contains non-ascii characters. Thanks Bruno Oliveira for the PR.
  * fix #1204: another error when collecting with a nasty
    __getattr__(). Thanks Florian Bruhin for the PR.
  * fix the summary printed when no tests did run. Thanks Florian
    Bruhin for the PR.
  * a number of documentation modernizations wrt good
    practices. Thanks Bruno Oliveira for the PR.
- update to version 2.8.3:
  * fix #1169: add __name__ attribute to testcases in TestCaseFunction
    to support the @unittest.skip decorator on functions and methods.
    Thanks Lee Kamentsky for the PR.
  * fix #1035: collecting tests if test module level obj has
    __getattr__().  Thanks Suor for the report and Bruno Oliveira /
    Tom Viner for the PR.
  * fix #331: don't collect tests if their failure cannot be reported
    correctly e.g. they are a callable instance of a class.
  * fix #1133: fixed internal error when filtering tracebacks where
    one entry belongs to a file which is no longer available.  Thanks
    Bruno Oliveira for the PR.
  * enhancement made to highlight in red the name of the failing tests
    so they stand out in the output.  Thanks Gabriel Reis for the PR.
  * add more talks to the documentation
  * extend documentation on the --ignore cli option
  * use pytest-runner for setuptools integration
  * minor fixes for interaction with OS X El Capitan system integrity
    protection (thanks Florian)
- Update to 2.8.2:
  - fix #1085: proper handling of encoding errors when passing encoded byte
    strings to pytest.parametrize in Python 2.
    Thanks Themanwithoutaplan for the report and Bruno Oliveira for the PR.
  - fix #1087: handling SystemError when passing empty byte strings to
    pytest.parametrize in Python 3.
    Thanks Paul Kehrer for the report and Bruno Oliveira for the PR.
  - fix #995: fixed internal error when filtering tracebacks where one entry
    was generated by an exec() statement.
    Thanks Daniel Hahler, Ashley C Straw, Philippe Gauthier and Pavel Savchenko
    for contributing and Bruno Oliveira for the PR.
- Update to 2.8.1
  - fix #1034: Add missing nodeid on pytest_logwarning call in
    addhook.  Thanks Simon Gomizelj for the PR.
  - 'deprecated_call' is now only satisfied with a DeprecationWarning or
    PendingDeprecationWarning. Before 2.8.0, it accepted any warning, and 2.8.0
    made it accept only DeprecationWarning (but not PendingDeprecationWarning).
    Thanks Alex Gaynor for the issue and Eric Hunsberger for the PR.
  - fix issue #1073: avoid calling __getattr__ on potential plugin objects.
    This fixes an incompatibility with pytest-django.  Thanks Andreas Pelme,
    Bruno Oliveira and Ronny Pfannschmidt for contributing and Holger Krekel
    for the fix.
  - Fix issue #704: handle versionconflict during plugin loading more
    gracefully.  Thanks Bruno Oliveira for the PR.
  - Fix issue #1064: ""--junitxml" regression when used with the
    "pytest-xdist" plugin, with test reports being assigned to the wrong tests.
    Thanks Daniel Grunwald for the report and Bruno Oliveira for the PR.
  - (experimental) adapt more SEMVER style versioning and change meaning of
    master branch in git repo: "master" branch now keeps the bugfixes, changes
    aimed for micro releases.  "features" branch will only be be released
    with minor or major pytest releases.
  - Fix issue #766 by removing documentation references to distutils.
    Thanks Russel Winder.
  - Fix issue #1030: now byte-strings are escaped to produce item node ids
    to make them always serializable.
    Thanks Andy Freeland for the report and Bruno Oliveira for the PR.
  - Python 2: if unicode parametrized values are convertible to ascii, their
    ascii representation is used for the node id.
  - Fix issue #411: Add __eq__ method to assertion comparison example.
    Thanks Ben Webb.
  - fix issue 877: properly handle assertion explanations with non-ascii repr
    Thanks Mathieu Agopian for the report and Ronny Pfannschmidt for the PR.
  - fix issue 1029: transform errors when writing cache values into pytest-warnings
- Update to 2.8.0
  - new ``--lf`` and ``-ff`` options to run only the last failing tests or
    "failing tests first" from the last run.  This functionality is provided
    through porting the formerly external pytest-cache plugin into pytest core.
    BACKWARD INCOMPAT: if you used pytest-cache's functionality to persist
    data between test runs be aware that we don't serialize sets anymore.
    Thanks Ronny Pfannschmidt for most of the merging work.
  - "-r" option now accepts "a" to include all possible reports, similar
    to passing "fEsxXw" explicitly (isse960).
    Thanks Abhijeet Kasurde for the PR.
  - avoid python3.5 deprecation warnings by introducing version
    specific inspection helpers, thanks Michael Droettboom.
  - fix issue562: @nose.tools.istest now fully respected.
  - fix issue934: when string comparison fails and a diff is too large to display
    without passing -vv, still show a few lines of the diff.
    Thanks Florian Bruhin for the report and Bruno Oliveira for the PR.
  - fix issue736: Fix a bug where fixture params would be discarded when combined
    with parametrization markers.
    Thanks to Markus Unterwaditzer for the PR.
  - fix issue710: introduce ALLOW_UNICODE doctest option: when enabled, the
    ``u`` prefix is stripped from unicode strings in expected doctest output. This
    allows doctests which use unicode to run in Python 2 and 3 unchanged.
    Thanks Jason R. Coombs for the report and Bruno Oliveira for the PR.
  - parametrize now also generates meaningful test IDs for enum, regex and class
    objects (as opposed to class instances).
    Thanks to Florian Bruhin for the PR.
  - Add 'warns' to assert that warnings are thrown (like 'raises').
    Thanks to Eric Hunsberger for the PR.
  - Fix issue683: Do not apply an already applied mark.  Thanks ojake for the PR.
  - Deal with capturing failures better so fewer exceptions get lost to
    /dev/null.  Thanks David Szotten for the PR.
  - fix issue730: deprecate and warn about the --genscript option.
    Thanks Ronny Pfannschmidt for the report and Christian Pommranz for the PR.
  - fix issue751: multiple parametrize with ids bug if it parametrizes class with
    two or more test methods. Thanks Sergey Chipiga for reporting and Jan
    Bednarik for PR.
  - fix issue82: avoid loading conftest files from setup.cfg/pytest.ini/tox.ini
    files and upwards by default (--confcutdir can still be set to override this).
    Thanks Bruno Oliveira for the PR.
  - fix issue768: docstrings found in python modules were not setting up session
    fixtures. Thanks Jason R. Coombs for reporting and Bruno Oliveira for the PR.
  - added `tmpdir_factory`, a session-scoped fixture that can be used to create
    directories under the base temporary directory. Previously this object was
    installed as a `_tmpdirhandler` attribute of the `config` object, but now it
    is part of the official API and using `config._tmpdirhandler` is
    deprecated.
    Thanks Bruno Oliveira for the PR.
  - fix issue808: pytest's internal assertion rewrite hook now implements the
    optional PEP302 get_data API so tests can access data files next to them.
    Thanks xmo-odoo for request and example and Bruno Oliveira for
    the PR.
  - rootdir and inifile are now displayed during usage errors to help
    users diagnose problems such as unexpected ini files which add
    unknown options being picked up by pytest. Thanks to Pavel Savchenko for
    bringing the problem to attention in #821 and Bruno Oliveira for the PR.
  - Summary bar now is colored yellow for warning
    situations such as: all tests either were skipped or xpass/xfailed,
    or no tests were run at all (this is a partial fix for issue500).
  - fix issue812: pytest now exits with status code 5 in situations where no
    tests were run at all, such as the directory given in the command line does
    not contain any tests or as result of a command line option filters
    all out all tests (-k for example).
    Thanks Eric Siegerman (issue812) and Bruno Oliveira for the PR.
  - Summary bar now is colored yellow for warning
    situations such as: all tests either were skipped or xpass/xfailed,
    or no tests were run at all (related to issue500).
    Thanks Eric Siegerman.
  - New `testpaths` ini option: list of directories to search for tests
    when executing pytest from the root directory. This can be used
    to speed up test collection when a project has well specified directories
    for tests, being usually more practical than configuring norecursedirs for
    all directories that do not contain tests.
    Thanks to Adrian for idea (#694) and Bruno Oliveira for the PR.
  - fix issue713: JUnit XML reports for doctest failures.
    Thanks Punyashloka Biswal.
  - fix issue970: internal pytest warnings now appear as "pytest-warnings" in
    the terminal instead of "warnings", so it is clear for users that those
    warnings are from pytest and not from the builtin "warnings" module.
    Thanks Bruno Oliveira.
  - Include setup and teardown in junitxml test durations.
    Thanks Janne Vanhala.
  - fix issue735: assertion failures on debug versions of Python 3.4+
  - new option ``--import-mode`` to allow to change test module importing
    behaviour to append to sys.path instead of prepending.  This better allows
    to run test modules against installated versions of a package even if the
    package under test has the same import root.  In this example::
    testing/__init__.py
    testing/test_pkg_under_test.py
    pkg_under_test/
    the tests will run against the installed version
    of pkg_under_test when ``--import-mode=append`` is used whereas
    by default they would always pick up the local version.  Thanks Holger Krekel.
  - pytester: add method ``TmpTestdir.delete_loaded_modules()``, and call it
    from ``inline_run()`` to allow temporary modules to be reloaded.
    Thanks Eduardo Schettino.
  - internally refactor pluginmanager API and code so that there
    is a clear distinction between a pytest-agnostic rather simple
    pluginmanager and the PytestPluginManager which adds a lot of
    behaviour, among it handling of the local conftest files.
    In terms of documented methods this is a backward compatible
    change but it might still break 3rd party plugins which relied on
    details like especially the pluginmanager.add_shutdown() API.
    Thanks Holger Krekel.
  - pluginmanagement: introduce ``pytest.hookimpl`` and
    ``pytest.hookspec`` decorators for setting impl/spec
    specific parameters.  This substitutes the previous
    now deprecated use of ``pytest.mark`` which is meant to
    contain markers for test functions only.
  - write/refine docs for "writing plugins" which now have their
    own page and are separate from the "using/installing plugins`` page.
  - fix issue732: properly unregister plugins from any hook calling
    sites allowing to have temporary plugins during test execution.
  - deprecate and warn about ``__multicall__`` argument in hook
    implementations.  Use the ``hookwrapper`` mechanism instead already
    introduced with pytest-2.7.
  - speed up pytest's own test suite considerably by using inprocess
    tests by default (testrun can be modified with --runpytest=subprocess
    to create subprocesses in many places instead).  The main
    APIs to run pytest in a test is "runpytest()" or "runpytest_subprocess"
    and "runpytest_inprocess" if you need a particular way of running
    the test.  In all cases you get back a RunResult but the inprocess
    one will also have a "reprec" attribute with the recorded events/reports.
  - fix monkeypatch.setattr("x.y", raising=False) to actually not raise
    if "y" is not a pre-existing attribute. Thanks Florian Bruhin.
  - fix issue741: make running output from testdir.run copy/pasteable
    Thanks Bruno Oliveira.
  - add a new ``--noconftest`` argument which ignores all ``conftest.py`` files.
  - add ``file`` and ``line`` attributes to JUnit-XML output.
  - fix issue890: changed extension of all documentation files from ``txt`` to
    ``rst``. Thanks to Abhijeet for the PR.
  - fix issue714: add ability to apply indirect=True parameter on particular argnames.
    Thanks Elizaveta239.
  - fix issue890: changed extension of all documentation files from ``txt`` to
    ``rst``. Thanks to Abhijeet for the PR.
  - fix issue957: "# doctest: SKIP" option will now register doctests as SKIPPED
    rather than PASSED.
    Thanks Thomas Grainger for the report and Bruno Oliveira for the PR.
  - issue951: add new record_xml_property fixture, that supports logging
    additional information on xml output. Thanks David Diaz for the PR.
  - issue949: paths after normal options (for example `-s`, `-v`, etc) are now
    properly used to discover `rootdir` and `ini` files.
    Thanks Peter Lauri for the report and Bruno Oliveira for the PR.
- Update to 2.7.3 (compared to 2.7.2)
  - Allow 'dev', 'rc', or other non-integer version strings in `importorskip`.
    Thanks to Eric Hunsberger for the PR.
  - fix issue856: consider --color parameter in all outputs (for example
  - -fixtures). Thanks Barney Gale for the report and Bruno Oliveira for the PR.
  - fix issue855: passing str objects as `plugins` argument to pytest.main
    is now interpreted as a module name to be imported and registered as a
    plugin, instead of silently having no effect.
    Thanks xmo-odoo for the report and Bruno Oliveira for the PR.
  - fix issue744: fix for ast.Call changes in Python 3.5+.  Thanks
    Guido van Rossum, Matthias Bussonnier, Stefan Zimmermann and
    Thomas Kluyver.
  - fix issue842: applying markers in classes no longer propagate this markers
    to superclasses which also have markers.
    Thanks xmo-odoo for the report and Bruno Oliveira for the PR.
  - preserve warning functions after call to pytest.deprecated_call. Thanks
    Pieter Mulder for PR.
  - fix issue854: autouse yield_fixtures defined as class members of
    unittest.TestCase subclasses now work as expected.
    Thannks xmo-odoo for the report and Bruno Oliveira for the PR.
  - fix issue833: --fixtures now shows all fixtures of collected test files, instead of just the
    fixtures declared on the first one.
    Thanks Florian Bruhin for reporting and Bruno Oliveira for the PR.
  - fix issue863: skipped tests now report the correct reason when a skip/xfail
    condition is met when using multiple markers.
    Thanks Raphael Pierzina for reporting and Bruno Oliveira for the PR.
  - optimized tmpdir fixture initialization, which should make test sessions
    faster (specially when using pytest-xdist). The only visible effect
    is that now pytest uses a subdirectory in the $TEMP directory for all
    directories created by this fixture (defaults to $TEMP/pytest-$USER).
    Thanks Bruno Oliveira for the PR.
- Update to 2.7.2
  - fix issue767: pytest.raises value attribute does not contain the exception
    instance on Python 2.6. Thanks Eric Siegerman for providing the test
    case and Bruno Oliveira for PR.
  - Automatically create directory for junitxml and results log.
    Thanks Aron Curzon.
  - fix issue713: JUnit XML reports for doctest failures.
    Thanks Punyashloka Biswal.
  - fix issue735: assertion failures on debug versions of Python 3.4+
    Thanks Benjamin Peterson.
  - fix issue114: skipif marker reports to internal skipping plugin;
    Thanks Floris Bruynooghe for reporting and Bruno Oliveira for the PR.
  - fix issue748: unittest.SkipTest reports to internal pytest unittest plugin.
    Thanks Thomas De Schampheleire for reporting and Bruno Oliveira for the PR.
  - fix issue718: failed to create representation of sets containing unsortable
    elements in python 2. Thanks Edison Gustavo Muenz.
  - fix issue756, fix issue752 (and similar issues): depend on py-1.4.29
    which has a refined algorithm for traceback generation.
- Move %%check to -doc subpackage to avoid dependency loop
  with new python3-hypothesis test dependency.
* Wed Jul 29 2015 toddrme2178@gmail.com
- Make tests conditional to avoid dependency loop.
* Mon Jul 27 2015 seife+obs@b1-systems.com
- revert update-alternatives change, causes OBS trouble
* Fri Jul 24 2015 seife+obs@b1-systems.com
- Change update-alternatives requirement to absolute path to fix
  non-SUSE distributions (RHEL7)
* Mon Jul  6 2015 rjschwei@suse.com
- Add python-xml as build dependency to avoid test failure with the
  Python version shipped in SLE 12
* Sun May 24 2015 toddrme2178@gmail.com
- Split documentation into separate package to avoid build loop
* Thu May 21 2015 toddrme2178@gmail.com
- It doesn't need Twisted, and the dependency causes a build cycle.
  So it is removed from BuildRequires
* Wed May 20 2015 toddrme2178@gmail.com
- Update to version 2.7.1:
  * fix issue731: do not get confused by the braces which may be
    present and unbalanced in an object's repr while collapsing
    False explanations.  Thanks Carl Meyer for the report and test
    case.
  * fix issue553: properly handling inspect.getsourcelines
    failures in FixtureLookupError which would lead to to an
    internal error, obfuscating the original problem. Thanks
    talljosh for initial diagnose/patch and Bruno Oliveira for
    final patch.
  * fix issue660: properly report scope-mismatch-access errors
    independently from ordering of fixture arguments.  Also
    avoid the pytest internal traceback which does not provide
    information to the user. Thanks Holger Krekel.
  * streamlined and documented release process.  Also all
    versions (in setup.py and documentation generation) are now
    read from _pytest/__init__.py. Thanks Holger Krekel.
  * fixed docs to remove the notion that yield-fixtures are
    experimental. They are here to stay :)  Thanks Bruno Oliveira.
  * Support building wheels by using environment markers for the
    requirements.  Thanks Ionel Maries Cristian.
  * fixed regression to 2.6.4 which surfaced e.g. in lost stdout
    capture printing when tests raised SystemExit. Thanks
    Holger Krekel.
  * reintroduced _pytest fixture of the pytester plugin which
    is used at least by pytest-xdist.
* Sun Apr  5 2015 tbechtold@suse.com
- update to 2.7.0:
  - fix issue435: make reload() work when assert rewriting is active.
    Thanks Daniel Hahler.
  - fix issue616: conftest.py files and their contained fixutres are now
    properly considered for visibility, independently from the exact
    current working directory and test arguments that are used.
    Many thanks to Eric Siegerman and his PR235 which contains
    systematic tests for conftest visibility and now passes.
    This change also introduces the concept of a ``rootdir`` which
    is printed as a new pytest header and documented in the pytest
    customize web page.
  - change reporting of "diverted" tests, i.e. tests that are collected
    in one file but actually come from another (e.g. when tests in a test class
    come from a base class in a different file).  We now show the nodeid
    and indicate via a postfix the other file.
  - add ability to set command line options by environment
    variable PYTEST_ADDOPTS.
  - added documentation on the new pytest-dev teams on bitbucket and
    github.  See https://pytest.org/latest/contributing.html .
    Thanks to Anatoly for pushing and initial work on this.
  - fix issue650: new option ``--docttest-ignore-import-errors`` which
    will turn import errors in doctests into skips.  Thanks Charles Cloud
    for the complete PR.
  - fix issue655: work around different ways that cause python2/3
    to leak sys.exc_info into fixtures/tests causing failures in 3rd party code
  - fix issue615: assertion re-writing did not correctly escape %% signs
    when formatting boolean operations, which tripped over mixing
    booleans with modulo operators.  Thanks to Tom Viner for the report,
    triaging and fix.
  - implement issue351: add ability to specify parametrize ids as a callable
    to generate custom test ids.  Thanks Brianna Laugher for the idea and
    implementation.
  - introduce and document new hookwrapper mechanism useful for plugins
    which want to wrap the execution of certain hooks for their purposes.
    This supersedes the undocumented ``__multicall__`` protocol which
    pytest itself and some external plugins use.  Note that pytest-2.8
    is scheduled to drop supporting the old ``__multicall__``
    and only support the hookwrapper protocol.
  - majorly speed up invocation of plugin hooks
  - use hookwrapper mechanism in builtin pytest plugins.
  - add a doctest ini option for doctest flags, thanks Holger Peters.
  - add note to docs that if you want to mark a parameter and the
    parameter is a callable, you also need to pass in a reason to disambiguate
    it from the "decorator" case.  Thanks Tom Viner.
  - "python_classes" and "python_functions" options now support glob-patterns
  for test discovery, as discussed in issue600. Thanks Ldiary Translations.
  - allow to override parametrized fixtures with non-parametrized ones and
    vice ver  sa (bubenkoff).
  - fix issue463: raise specific error for 'parameterize' misspelling
    (pfctdayelise  ).
  - On failure, the ``sys.last_value``, ``sys.last_type`` and
    ``sys.last_traceback`` are set, so that a user can inspect the error
    via postmortem debugging (almarklein).
- Bump Requires/BuildRequires for python-py
* Wed Mar 25 2015 mcihar@suse.cz
- Add optional dependencies for testsuite as BuildRequires.
* Wed Mar 25 2015 mcihar@suse.cz
- Update to 2.6.4:
  - Improve assertion failure reporting on iterables, by using ndiff and pprint.
  - removed outdated japanese docs from source tree.
  - docs for "pytest_addhooks" hook.  Thanks Bruno Oliveira.
  - updated plugin index docs.  Thanks Bruno Oliveira.
  - fix issue557: with "-k" we only allow the old style "-" for negation
    at the beginning of strings and even that is deprecated.  Use "not" instead.
    This should allow to pick parametrized tests where "-" appeared in the parameter.
  - fix issue604: Escape %% character in the assertion message.
  - fix issue620: add explanation in the --genscript target about what
    the binary blob means. Thanks Dinu Gherman.
  - fix issue614: fixed pastebin support.
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Sun Oct  5 2014 toms@opensuse.org
- Update to 2.6.3
  - No longer show line numbers in the –verbose output, the output
    is now purely the nodeid. The line number is still shown in
    failure reports. Thanks Floris Bruynooghe.
  - fix issue437 where assertion rewriting could cause pytest-xdist
    slaves to collect different tests.
    Thanks Bruno Oliveira.
  - fix issue555: add “errors” attribute to capture-streams to
    satisfy some distutils and possibly other code accessing sys.stdout.errors.
  - fix issue547 capsys/capfd also work when output capturing (“-s”)
    is disabled.
  - address issue170: allow pytest.mark.xfail(...) to specify expected
    exceptions via an optional “raises=EXC” argument where EXC can be
    a single exception or a tuple of exception classes.
    Thanks David Mohr for the complete PR.
  - fix integration of pytest with unittest.mock.patch decorator when
    it uses the “new” argument.
    Thanks Nicolas Delaby for test and PR.
  - fix issue with detecting conftest files if the arguments contain
    ”::” node id specifications (copy pasted from “-v” output)
  - fix issue544 by only removing “@NUM” at the end of ”::” separated
    parts and if the part has an ”.py” extension  don’t use py.std
    import helper, rather import things directly.
    Thanks Bruno Oliveira.
  See for other releases: http://pytest.org/latest/changelog.html
* Wed Jul 30 2014 toddrme2178@gmail.com
- Update to 2.6.0
  - Cache exceptions from fixtures according to their scope (issue 467).
  - fix issue537: Avoid importing old assertion reinterpretation code by default.
  - fix issue364: shorten and enhance tracebacks representation by default.
    The new "--tb=auto" option (default) will only display long tracebacks
    for the first and last entry.  You can get the old behaviour of printing
    all entries as long entries with "--tb=long".  Also short entries by
    default are now printed very similarly to "--tb=native" ones.
  - fix issue514: teach assertion reinterpretation about private class attributes
  - change -v output to include full node IDs of tests.  Users can copy
    a node ID from a test run, including line number, and use it as a
    positional argument in order to run only a single test.
  - fix issue 475: fail early and comprehensible if calling
    pytest.raises with wrong exception type.
  - fix issue516: tell in getting-started about current dependencies.
  - cleanup setup.py a bit and specify supported versions. Thanks Jurko
    Gospodnetic for the PR.
  - change XPASS colour to yellow rather then red when tests are run
    with -v.
  - fix issue473: work around mock putting an unbound method into a class
    dict when double-patching.
  - fix issue498: if a fixture finalizer fails, make sure that
    the fixture is still invalidated.
  - fix issue453: the result of the pytest_assertrepr_compare hook now gets
    it's newlines escaped so that format_exception does not blow up.
  - internal new warning system: pytest will now produce warnings when
    it detects oddities in your test collection or execution.
    Warnings are ultimately sent to a new pytest_logwarning hook which is
    currently only implemented by the terminal plugin which displays
    warnings in the summary line and shows more details when -rw (report on
    warnings) is specified.
  - change skips into warnings for test classes with an __init__ and
    callables in test modules which look like a test but are not functions.
  - fix issue436: improved finding of initial conftest files from command
    line arguments by using the result of parse_known_args rather than
    the previous flaky heuristics.  Thanks Marc Abramowitz for tests
    and initial fixing approaches in this area.
  - fix issue #479: properly handle nose/unittest(2) SkipTest exceptions
    during collection/loading of test modules.  Thanks to Marc Schlaich
    for the complete PR.
  - fix issue490: include pytest_load_initial_conftests in documentation
    and improve docstring.
  - fix issue472: clarify that ``pytest.config.getvalue()`` cannot work
    if it's triggered ahead of command line parsing.
  - merge PR123: improved integration with mock.patch decorator on tests.
  - fix issue412: messing with stdout/stderr FD-level streams is now
    captured without crashes.
  - fix issue483: trial/py33 works now properly.  Thanks Daniel Grana for PR.
  - improve example for pytest integration with "python setup.py test"
    which now has a generic "-a" or "--pytest-args" option where you
    can pass additional options as a quoted string.  Thanks Trevor Bekolay.
  - simplified internal capturing mechanism and made it more robust
    against tests or setups changing FD1/FD2, also better integrated
    now with pytest.pdb() in single tests.
  - improvements to pytest's own test-suite leakage detection, courtesy of PRs
    from Marc Abramowitz
  - fix issue492: avoid leak in test_writeorg.  Thanks Marc Abramowitz.
  - fix issue493: don't run tests in doc directory with ``python setup.py test``
    (use tox -e doctesting for that)
  - fix issue486: better reporting and handling of early conftest loading failures
  - some cleanup and simplification of internal conftest handling.
  - work a bit harder to break reference cycles when catching exceptions.
    Thanks Jurko Gospodnetic.
  - fix issue443: fix skip examples to use proper comparison.  Thanks Alex
    Groenholm.
  - support nose-style ``__test__`` attribute on modules, classes and
    functions, including unittest-style Classes.  If set to False, the
    test will not be collected.
  - fix issue512: show "<notset>" for arguments which might not be set
    in monkeypatch plugin.  Improves output in documentation.
* Tue Jun 10 2014 mvyskocil@opensuse.org
- Add setuptools dependency as py.test launcher does import pkg_resources
* Wed Mar 12 2014 speilicke@suse.com
- Update to version 2.5.2:
  - fix issue409 -- better interoperate with cx_freeze by not
    trying to import from collections.abc which causes problems
    for py27/cx_freeze.  Thanks Wolfgang L. for reporting and tracking it down.
  - fixed docs and code to use "pytest" instead of "py.test" almost everywhere.
    Thanks Jurko Gospodnetic for the complete PR.
  - fix issue425: mention at end of "py.test -h" that --markers
    and --fixtures work according to specified test path (or current dir)
  - fix issue413: exceptions with unicode attributes are now printed
    correctly also on python2 and with pytest-xdist runs. (the fix
    requires py-1.4.20)
  - copy, cleanup and integrate py.io capture
    from pylib 1.4.20.dev2 (rev 13d9af95547e)
  - address issue416: clarify docs as to conftest.py loading semantics
  - fix issue429: comparing byte strings with non-ascii chars in assert
    expressions now work better.  Thanks Floris Bruynooghe.
  - make capfd/capsys.capture private, its unused and shouldnt be exposed
* Thu Jan 30 2014 speilicke@suse.com
- Re-add python-argparse requirement for SP3
* Fri Jan  3 2014 mvyskocil@suse.com
- Update to 2.5.1:
  + merge new documentation styling PR from Tobias Bieniek.
  + fix issue403: allow parametrize of multiple same-name functions within
    a collection node.
  + Allow parameterized fixtures to specify the ID of the parameters by
    adding an ids argument to pytest.fixture() and pytest.yield_fixture().
  + fix issue404 by always using the binary xml escape in the junitxml
    plugin.
  + fix issue407: fix addoption docstring to point to argparse instead of
    optparse.
  * 2.5.0:
  + dropped python2.5 from automated release testing of pytest itself
    which means it's probably going to break soon
  + simplified and fixed implementation for calling finalizers when
    parametrized fixtures or function arguments are involved.  finalization
    is now performed lazily at setup time instead of in the "teardown phase".
  + PR90: add --color=yes|no|auto option to force terminal coloring
    mode ("auto" is default).
  + fix issue319 - correctly show unicode in assertion errors. Also means
    we depend on py>=1.4.19 now.
  + fix issue396 - correctly sort and finalize class-scoped parametrized
    tests independently from number of methods on the class.
  + refix issue323 in a better way -- parametrization should now never
    cause Runtime Recursion errors because the underlying algorithm
    for re-ordering tests per-scope/per-fixture is not recursive
    anymore
  + fix issue290 - there is preliminary support now for parametrizing
    with repeated same values (sometimes useful to to test if calling
    a second time works as with the first time).
  + close issue240 - document precisely how pytest module importing
    works, discuss the two common test directory layouts, and how it
    interacts with PEP420-namespace packages.
  + fix issue246 fix finalizer order to be LIFO on independent fixtures
    depending on a parametrized higher-than-function scoped fixture.
    (was quite some effort so please bear with the complexity of
    this sentence :)
  + fix issue244 by implementing special index for parameters to only use
    indices for paramentrized test ids
  + fix issue287 by running all finalizers but saving the exception
    from the first failing finalizer and re-raising it so teardown will
    still have failed.  We reraise the first failing exception because
    it might be the cause for other finalizers to fail.
  + fix ordering when mock.patch or other standard decorator-wrappings
    are used with test methods.  This fixues issue346 and should
    help with random "xdist" collection failures.  Thanks to
    Ronny Pfannschmidt and Donald Stufft for helping to isolate it.
  + and many more, see CHANGELOG for details
- require python3-py at least 1.4.19
- mark /etc/alternatives/py.test as ghost file for openSUSE 12.3+
- skip test_simple.yml from %%check
* Thu Sep 19 2013 speilicke@suse.com
- Skip running tests on SLE_11_SP2
* Tue Jun 18 2013 speilicke@suse.com
- Use update-alternatives
* Mon Jun 17 2013 speilicke@suse.com
- Update to version 2.3.5:
  + never consider a fixture function for test function collection
  + allow re-running of test items / helps to fix pytest-reruntests plugin
    and also help to keep less fixture/resource references alive
  + put captured stdout/stderr into junitxml output even for passing tests
    (thanks Adam Goucher)
  + Issue 265 - integrate nose setup/teardown with setupstate
    so it doesnt try to teardown if it did not setup
  + issue 271 - dont write junitxml on slave nodes
  + Issue 274 - dont try to show full doctest example
    when doctest does not know the example location
  + issue 280 - disable assertion rewriting on buggy CPython 2.6.0
  + inject "getfixture()" helper to retrieve fixtures from doctests,
    thanks Andreas Zeidler
  + issue 259 - when assertion rewriting, be consistent with the default
    source encoding of ASCII on Python 2
  + issue 251 - report a skip instead of ignoring classes with init
  + issue250 unicode/str mixes in parametrization names and values now works
  + issue257, assertion-triggered compilation of source ending in a
    comment line doesn't blow up in python2.5 (fixed through py>=1.4.13.dev6)
  + fix --genscript option to generate standalone scripts that also
    work with python3.3 (importer ordering)
  + issue171 - in assertion rewriting, show the repr of some
    global variables
  + fix option help for "-k"
  + move long description of distribution into README.rst
  + improve docstring for metafunc.parametrize()
  + fix bug where using capsys with pytest.set_trace() in a test
    function would break when looking at capsys.readouterr()
  + allow to specify prefixes starting with "_" when
    customizing python_functions test discovery. (thanks Graham Horler)
  + improve PYTEST_DEBUG tracing output by puting
    extra data on a new lines with additional indent
  + ensure OutcomeExceptions like skip/fail have initialized exception attributes
  + issue 260 - don't use nose special setup on plain unittest cases
  + fix issue134 - print the collect errors that prevent running specified test items
  + fix issue266 - accept unicode in MarkEvaluator expressions
* Thu May  2 2013 speilicke@suse.com
- Enable testsuite
* Sat Apr 20 2013 toms@opensuse.org
- Updated to version 2.3.4
  For details, see
  http://pytest.org/latest/changelog.html#changes-between-2-3-3-and-2-3-4
  No releases before 2.3.4 published (except the initial release).
- SPEC file changes:
  * Added build conditional with tests
  * Improved package description
* Mon Feb 20 2012 saschpe@gmx.de
- Initial version
